@@ -216,6 +216,9 @@ chxj_node_exchange(
         if (handlers[tagH6].end_tag_handler)
           handlers[tagH6].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
 
@@ -233,11 +236,10 @@ chxj_node_exchange(
         if (handlers[tagP].end_tag_handler)
           handlers[tagP].end_tag_handler(pdoc, child);
       }
-      else
       /*----------------------------------------------------------------------*/
       /* <PRE>                                                                */
       /*----------------------------------------------------------------------*/
-      if (strcasecmp(name, "pre") == 0) {
+      else if (strcasecmp(name, "pre") == 0) {
         if (handlers[tagPRE].start_tag_handler) 
           handlers[tagPRE].start_tag_handler(pdoc, child);
 
@@ -246,6 +248,19 @@ chxj_node_exchange(
         if (handlers[tagPRE].end_tag_handler)
           handlers[tagPRE].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <PLAINTEXT>                                                          */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "plaintext") == 0) {
+        if (handlers[tagPLAINTEXT].start_tag_handler) 
+          handlers[tagPLAINTEXT].start_tag_handler(pdoc, child);
+
+        if (handlers[tagPLAINTEXT].end_tag_handler)
+          handlers[tagPLAINTEXT].end_tag_handler(pdoc, child);
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'n':
@@ -262,6 +277,9 @@ chxj_node_exchange(
         if (handlers[tagNOBR].end_tag_handler)
           handlers[tagNOBR].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'u':
@@ -278,6 +296,9 @@ chxj_node_exchange(
         if (handlers[tagUL].end_tag_handler)
           handlers[tagUL].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'l':
@@ -320,6 +341,9 @@ chxj_node_exchange(
         if (handlers[tagLABEL].end_tag_handler)
           handlers[tagLABEL].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       
       break;
 
@@ -350,6 +374,16 @@ chxj_node_exchange(
         if (handlers[tagOPTION].end_tag_handler)
           handlers[tagOPTION].end_tag_handler(pdoc, child);
       }
+      else
+      /*----------------------------------------------------------------------*/
+      /* <OBJECT>                                                             */
+      /*----------------------------------------------------------------------*/
+      if (strcasecmp(name, "object") == 0) {
+        /* ignore object block */
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
 
       break;
 
@@ -367,6 +401,33 @@ chxj_node_exchange(
         if (handlers[tagMETA].end_tag_handler)
           handlers[tagMETA].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <MENU>                                                               */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "menu") == 0) {
+        if (handlers[tagMENU].start_tag_handler) 
+          handlers[tagMENU].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagMENU].end_tag_handler)
+          handlers[tagMENU].end_tag_handler(pdoc, child);
+      }
+      /*----------------------------------------------------------------------*/
+      /* <MARQUEE>                                                            */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "marquee") == 0) {
+        if (handlers[tagMARQUEE].start_tag_handler) 
+          handlers[tagMARQUEE].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagMARQUEE].end_tag_handler)
+          handlers[tagMARQUEE].end_tag_handler(pdoc, child);
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'b':
@@ -412,8 +473,7 @@ chxj_node_exchange(
       /*----------------------------------------------------------------------*/
       /* <BR>                                                                 */
       /*----------------------------------------------------------------------*/
-      else
-      if (strcasecmp(name, "br") == 0) {
+      else if (strcasecmp(name, "br") == 0) {
         if (handlers[tagBR].start_tag_handler) 
           handlers[tagBR].start_tag_handler(pdoc, child);
 
@@ -422,6 +482,33 @@ chxj_node_exchange(
         if (handlers[tagBR].end_tag_handler)
           handlers[tagBR].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <BLOCKQUOTE>                                                         */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "blockquote") == 0) {
+        if (handlers[tagBLOCKQUOTE].start_tag_handler) 
+          handlers[tagBLOCKQUOTE].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagBLOCKQUOTE].end_tag_handler)
+          handlers[tagBLOCKQUOTE].end_tag_handler(pdoc, child);
+      }
+      /*----------------------------------------------------------------------*/
+      /* <BLINK>                                                              */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "blink") == 0) {
+        if (handlers[tagBLINK].start_tag_handler) 
+          handlers[tagBLINK].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagBLINK].end_tag_handler)
+          handlers[tagBLINK].end_tag_handler(pdoc, child);
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'a':
@@ -438,6 +525,9 @@ chxj_node_exchange(
         if (handlers[tagA].end_tag_handler)
           handlers[tagA].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'f':
@@ -480,6 +570,9 @@ chxj_node_exchange(
         if (handlers[tagFIELDSET].end_tag_handler)
           handlers[tagFIELDSET].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'i':
@@ -509,6 +602,9 @@ chxj_node_exchange(
         if (handlers[tagIMG].end_tag_handler)
           handlers[tagIMG].end_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 's':
@@ -565,6 +661,16 @@ chxj_node_exchange(
         if (handlers[tagSMALL].end_tag_handler)
           handlers[tagSMALL].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <SCRIPT>                                                             */
+      /*----------------------------------------------------------------------*/
+      else 
+      if (strcasecmp(name, "script") == 0) {
+        /* ignore script block */
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
   
     case 'd':
@@ -581,6 +687,57 @@ chxj_node_exchange(
         if (handlers[tagDIV].end_tag_handler)
           handlers[tagDIV].end_tag_handler(pdoc, child);
       }
+      /*----------------------------------------------------------------------*/
+      /* <DIR>                                                                */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "dir") == 0) {
+        if (handlers[tagDIR].start_tag_handler) 
+          handlers[tagDIR].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagDIR].end_tag_handler)
+          handlers[tagDIR].end_tag_handler(pdoc, child);
+      }
+      /*----------------------------------------------------------------------*/
+      /* <DL>                                                                 */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "dl") == 0) {
+        if (handlers[tagDL].start_tag_handler) 
+          handlers[tagDL].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagDL].end_tag_handler)
+          handlers[tagDL].end_tag_handler(pdoc, child);
+      }
+      /*----------------------------------------------------------------------*/
+      /* <DT>                                                                 */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "dt") == 0) {
+        if (handlers[tagDT].start_tag_handler) 
+          handlers[tagDT].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagDT].end_tag_handler)
+          handlers[tagDT].end_tag_handler(pdoc, child);
+      }
+      /*----------------------------------------------------------------------*/
+      /* <DD>                                                                 */
+      /*----------------------------------------------------------------------*/
+      else if (strcasecmp(name, "dd") == 0) {
+        if (handlers[tagDD].start_tag_handler) 
+          handlers[tagDD].start_tag_handler(pdoc, child);
+
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+
+        if (handlers[tagDD].end_tag_handler)
+          handlers[tagDD].end_tag_handler(pdoc, child);
+      }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 'c':
@@ -616,6 +773,9 @@ chxj_node_exchange(
           }
         }
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     case 't':
@@ -718,6 +878,9 @@ chxj_node_exchange(
         if (handlers[tagTEXT].start_tag_handler)
           handlers[tagTEXT].start_tag_handler(pdoc, child);
       }
+      else {
+        chxj_node_exchange(spec, r, pdoc, doc, child, indent+1);
+      }
       break;
 
     default:
