@@ -69,10 +69,9 @@ qs_get_value_attr(Doc* doc, Node* node, request_rec* r)
  *         not found.
  */
 char*
-qs_get_checked_attr(Doc* doc, Node* tag, request_rec* r)
+qs_get_checked_attr(Doc* doc, Node* tag, request_rec *UNUSED(r))
 {
   Attr*        attr;
-  int          found_flag = 0;
 
   /*--------------------------------------------------------------------------*/
   /* The object tag node is scanned.                                          */
@@ -85,17 +84,13 @@ qs_get_checked_attr(Doc* doc, Node* tag, request_rec* r)
       /*----------------------------------------------------------------------*/
       /* The VALUE attribute was found.                                       */
       /*----------------------------------------------------------------------*/
-      found_flag = 1;
-      break;
+      return name;
     }
   }
-  if (! found_flag)
-    /*------------------------------------------------------------------------*/
-    /* not found                                                              */
-    /*------------------------------------------------------------------------*/
-    return NULL;
-
-  return qs_get_value_attr(doc, tag, r);
+  /*------------------------------------------------------------------------*/
+  /* not found                                                              */
+  /*------------------------------------------------------------------------*/
+  return NULL;
 }
 
 
@@ -154,14 +149,14 @@ qs_alloc_zero_byte_string(request_rec* r)
 /**
  * A consecutive head and the last WHITESPACE are removed.
  *
- * @param r    [i]   To use POOL, the pointer to request_rec is specified.
+ * @param p    [i]   To use POOL
  * @param s    [i]   The character string that should be removed is specified.
  * @return The character string that has been removed is returned.
  */
 char*
-qs_trim_string(request_rec* r, char* s)
+qs_trim_string(apr_pool_t *p, char* s)
 {
-  char* ss = apr_pstrdup(r->pool, s);
+  char* ss = apr_pstrdup(p, s);
   int len = strlen(s);
   int ii;
 
