@@ -139,7 +139,7 @@ chxj_headers_fixup(request_rec *r)
   device_table*       spec;
 
   DBG(r, "start chxj_headers_fixup()");
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
   user_agent = (char*)apr_table_get(r->headers_in, HTTP_USER_AGENT);
   spec = chxj_specified_device(r, user_agent);
@@ -203,7 +203,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len, device_table *s
   DBG(r,"start of chxj_exchange() input:[%.*s]", (int)*len, *src);
   dst  = apr_pstrcat(r->pool, (char*)*src, NULL);
 
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
 
   entryp = chxj_apply_convrule(r, dconf->convrules);
@@ -692,7 +692,6 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
   }
 
 
-
   for (b = APR_BRIGADE_FIRST(bb);
        b != APR_BRIGADE_SENTINEL(bb); 
        b = APR_BUCKET_NEXT(b)) {
@@ -819,11 +818,7 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
           for (child = qs_get_child_node(&doc,root);
                child ;
                child = qs_get_next_node(&doc,child)) {
-        
-            char* name;
-        
-            name = qs_get_node_name(&doc,child);
-        
+            char *name = qs_get_node_name(&doc,child);
             if (strcasecmp("qrcode",name) == 0) {
               sts++;
               break;
@@ -838,7 +833,7 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
               ERR(r, "qrcode create failed.");
               return sts;
             }
-            r->content_type = apr_psprintf(r->pool, "image/jpg");
+            r->content_type = apr_psprintf(r->pool, "image/jpeg");
           }
         }
 
@@ -861,23 +856,13 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
 
             memset(tmp, 0, ctx->len + 1);
             memcpy(tmp, ctx->buffer, ctx->len);
-
-#if 0
-            DBG(r, "input data=[%s]", tmp);
-#endif
-
-
             ctx->buffer = 
               chxj_exchange_image(r, 
                                   (const char**)&tmp,
                                   (apr_size_t*)&ctx->len);
-
-            if (ctx->buffer == NULL)
+            if (ctx->buffer == NULL) {
               ctx->buffer = tmp;
-
-#if 0
-            DBG(r, "output data=[%.*s]", ctx->len,ctx->buffer);
-#endif
+            }
           }
         }
 
@@ -1015,7 +1000,7 @@ chxj_input_filter(ap_filter_t*        f,
     return ap_get_brigade(f->next, bb, mode, block, readbytes);
   }
 
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
   user_agent = (char*)apr_table_get(r->headers_in, "User-Agent");
 
   if (ctx && ctx->entryp) entryp = ctx->entryp;
@@ -1277,7 +1262,7 @@ chxj_insert_filter(request_rec *r)
   chxjconvrule_entry* entryp;
 DBG(r, "start chxj_insert_filter()");
 
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
   user_agent = (char*)apr_table_get(r->headers_in, HTTP_USER_AGENT);
   spec = chxj_specified_device(r, user_agent);
